Learn R Programming

CatDyn (version 1.1-1)

CatDynCor: Correlation Plot Among Parameter Estimates

Description

It extracts the correlation matrices output by CatDynFit() from several model fits and plots histograms of pairwise correlation coefficients.

Usage

CatDynCor(x, ttl, method, arr)

Arguments

x

A list of model objects of class catdyn output by CatDynFit().

ttl

A character vector to use as title of each histogram.

method

A character vector of numerical methods to extract correlation matrices.

arr

A numerical vector of length 2 used to organize the panels containing each histogram. Passed as is to par().

Value

A multiple panel correlation plot.

Details

The arguments x, ttl, and method must be of the same length.

It might be useful to examine the results of different numerical methods applied to the same model with this function. To do this just repeat the name of the object in x and specify the different numerical methods in method.

Examples

Run this code
# NOT RUN {
#See examples for CatDynFit().
# }

Run the code above in your browser using DataLab