Learn R Programming

CatDyn (version 1.1-1)

cor2cov: Correlation Matrix to Covariance Matrix Conversion

Description

Function to convert a correlation matrix to a covariance matrix.

Usage

cor2cov(cor.mat, sd, discrepancy = 1e-05)

Arguments

cor.mat

The correlation matrix to be converted.

sd

A vector that contains the standard deviations of the variables in the correlation matrix.

discrepancy

A neighborhood of 1, such that numbers on the main diagonal of the correlation matrix will be considered as equal to 1 if they fall in this neighborhood

Details

This function was copied from package MBESS.

The correlation matrix to convert can be either symmetric or triangular. The covariance matrix returned is always a symmetric matrix.