Learn R Programming

CatDyn (version 1.1-1)

gayhake: Industrial and Artisanal Catch and Effort Data from the Chilean Hake Fishery

Description

Exhaustive recorded operational activity of the Merluccius gayi two fleet fishery off Central Chile in 2006.

Usage

data("gayhake")

Arguments

Format

A data frame with 53 observations on the following 7 variables.

TimeStep

a numeric vector

Catch.Ind.kg

a numeric vector

NShips.Ind

a numeric vector

Body.Ind.g

a numeric vector

Catch.Art.kg

a numeric vector

NShips.Art

a numeric vector

Body.Art.g

a numeric vector

Examples

Run this code
# NOT RUN {
data(gayhake)
# }

Run the code above in your browser using DataLab