Learn R Programming

CatDyn (version 1.1-1)

gayhakelm: Length and Month data of Chilean hake from Artisanal Fishery

Description

A small sample from hundreds of thousand of records of length by month from individual fish captured by artisanal fishing boats.

Usage

data("gayhakelm")

Arguments

Format

A data frame with 600 observations on the following 2 variables.

Month

a numeric vector

lon.cm

a numeric vector

Examples

Run this code
# NOT RUN {
data(gayhakelm)
# }

Run the code above in your browser using DataLab