Learn R Programming

CatDyn (version 1.1-1)

gayhakelw: Length and Weight data of Chilean hake from Artisanal Fishery

Description

A small sample from hundreds of thousand of records of length and weight of individual fish captured by artisanal fishing boats.

Usage

data("gayhakelw")

Arguments

Format

A data frame with 250 observations on the following 2 variables.

Length.cm

a numeric vector

Weight.kg

a numeric vector

Examples

Run this code
# NOT RUN {
data(gayhakelw)
# }

Run the code above in your browser using DataLab