Learn R Programming

CatDyn (version 1.1-1)

lolgahi: Industrial Trawling Data from the Squid Fishery of the Falkland Islands

Description

Exhaustive recorded operational activity of the Loligo gahi fleet off the Falkland Islands during the summer season of 1990.

Usage

data("lolgahi")

Arguments

Format

A data frame with 120 observations on the following 6 variables.

obscat

a numeric vector

obseff

a numeric vector

obsmbm

a numeric vector

References

Roa-Ureta, R. H. 2012. ICES Journal of Marine Science 69(8):1403-1415.

Examples

Run this code
# NOT RUN {
data(lolgahi)
# }

Run the code above in your browser using DataLab