Learn R Programming

CatDyn (version 1.1-1)

m.hoenig: Marine animals natural mortality and longevity database

Description

A database of natural mortality estimates and longetvity in fish, cetaceans and molluscs compiled by Prof. John M. Hoenig.

Usage

data("m.hoenig")

Arguments

Format

A data frame with 123 observations on the following 2 variables.

maxage

a numeric vector

natmort

a numeric vector

Details

Mortality rates in 1/yr and longevity in yr.

References

Hoening, J.M. 2005. Empirical use of longevity data to estimate mortality rates. SEDAR33-RD17. SEDAR, North Charleston, SC. 8 pp.

Examples

Run this code
# NOT RUN {
data(m.hoenig)
# }

Run the code above in your browser using DataLab