The arguments x, ttl, and method must be of the same length.
It might be useful to examine the results of different numerical methods applied
to the same model with this function. To do this just repeat the name of the
object in x and specify the different numerical methods in method.