Function to convert a correlation matrix to a covariance matrix.
cor2cov(cor.mat, sd, discrepancy = 1e-05)The correlation matrix to be converted.
A vector that contains the standard deviations of the variables in the correlation matrix.
A neighborhood of 1, such that numbers on the main diagonal of the correlation matrix will be considered as equal to 1 if they fall in this neighborhood
This function was copied from package MBESS.
The correlation matrix to convert can be either symmetric or triangular. The covariance matrix returned is always a symmetric matrix.