powered by
A small sample from hundreds of thousand of records of length by month from individual fish captured by artisanal fishing boats.
data("gayhakelm")
A data frame with 600 observations on the following 2 variables.
Month
a numeric vector
lon.cm
# NOT RUN { data(gayhakelm) # }
Run the code above in your browser using DataLab