powered by
A small sample from hundreds of thousand of records of length and weight of individual fish captured by artisanal fishing boats.
data("gayhakelw")
A data frame with 250 observations on the following 2 variables.
Length.cm
a numeric vector
Weight.kg
# NOT RUN { data(gayhakelw) # }
Run the code above in your browser using DataLab