powered by
Exhaustive recorded operational activity of the Loligo gahi fleet off the Falkland Islands during the summer season of 1990.
data("lolgahi")
A data frame with 120 observations on the following 6 variables.
obscat
a numeric vector
obseff
obsmbm
Roa-Ureta, R. H. 2012. ICES Journal of Marine Science 69(8):1403-1415.
# NOT RUN { data(lolgahi) # }
Run the code above in your browser using DataLab